"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.autoGenerateId = exports.LocStringArray = void 0;
const smartloc_1 = require("./smartloc");
const literal_1 = require("./literal");
const js_sha1_1 = __importDefault(require("js-sha1"));
class JoinedString {
    constructor(strs, join) {
        this.strs = strs;
        this.join = join;
        literal_1.setIsLoc(this);
    }
    get id() {
        return undefined;
    }
    toString(locale) {
        return this.strs
            .map(x => x && (typeof x === 'string' ? x : x.toString(locale)))
            .join(this.join);
    }
    toJSON() {
        return this.toString();
    }
    transform(transformer) {
        return new smartloc_1.TransformedLoc(this, transformer);
    }
}
class LocStringArray {
    constructor(strs) {
        this.strs = strs;
    }
    toJSON() {
        return this.strs.map(x => x && (typeof x === 'string' ? x : x.toJSON()));
    }
    map(fn) {
        return new LocStringArray(this.strs.map(fn));
    }
    slice(start, end) {
        return new LocStringArray(this.strs.slice(start, end));
    }
    join(join) {
        return new JoinedString(this.strs, join);
    }
    toArray() {
        return [...this.strs];
    }
}
exports.LocStringArray = LocStringArray;
function autoGenerateId(str) {
    const sha = js_sha1_1.default(str.join('|'));
    return 'sha1.' + sha;
}
exports.autoGenerateId = autoGenerateId;
//# sourceMappingURL=utils.js.map